@@ -2,7 +2,5 @@ from monascastatsd.client import Client
 from monascastatsd.connection import Connection
 from monascastatsd.counter import Counter
 from monascastatsd.gauge import Gauge
-from monascastatsd.histogram import Histogram
 from monascastatsd.metricbase import MetricBase
-from monascastatsd.set import Set
 from monascastatsd.timer import Timer
