@@ -38,10 +38,10 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-from monascastatsd.metricbase import MetricBase
+from monascastatsd import metricbase
 
 
-class Counter(MetricBase):
+class Counter(metricbase.MetricBase):
 
     def __init__(self, name, connection, dimensions=None):
         super(self.__class__, self).__init__(name=name,
